@@ -1,6 +1,10 @@
 //! Additional extractors.
 
 mod cached;
+
+#[cfg(feature = "form")]
+mod form;
+
 #[cfg(feature = "cookie")]
 pub mod cookie;
 
@@ -14,3 +18,6 @@ pub use self::cookie::PrivateCookieJar;
 
 #[cfg(feature = "cookie-signed")]
 pub use self::cookie::SignedCookieJar;
+
+#[cfg(feature = "form")]
+pub use self::form::Form;
